LoadPackage("atlasrep");
LoadPackage("io");

checkD := function(gr, c)
  local sg, x, y;
  x := Representative(c);
  for y in c do
    if not (x*y)^2 = (y*x)^2 then 
      sg := Subgroup(gr, [x,y]);
      if IsConjugate(sg, x, y) = false then
        return [x,y];
      fi;
    fi;
  od;
  return fail;
end;

LogTo("step3.log");

gr := DirectProduct(SymmetricGroup(5), AtlasGroup("M22.2"));
ct := CharacterTable(gr);
cc := ConjugacyClasses(gr);

bg := BaseOfGroup(gr);
Print("Base of Group: ", bg, "\n");

f := IO_File("step3.rec", "w");
IO_WriteLine(f,"### The format for classinfo is [ r, s, order, comment ]");
IO_WriteLine(f,"data := rec(");
IO_WriteLine(f,"  base := ", bg, ",");
IO_WriteLine(f,"  group := \"S5xM22.2\",");
IO_WriteLine(f,"  comments := \"For classes with representatives of order 4, 8, 33, 42, 55, 66, 70\",");
IO_WriteLine(f,"  classinfo := [");

for c in cc do
  g := Representative(c);
  if Order(g) in [4, 8, 33, 42, 55, 66, 70] then
    Print("\nChecking a conjugacy class with representative of order ", Order(g), "\n");
    rs := checkD(gr, c); 
    if not rs = fail then
      Print("r:=", OnTuples(bg, rs[1]), "\n");
      Print("s:=", OnTuples(bg, rs[2]), "\n");
      IO_WriteLine(f, "    [ ", OnTuples(bg, rs[1]), ", ", OnTuples(bg, rs[2]), ", ", Order(g), ", \"D\" ],");
    else
      Print("Size of the conjugacy class: ", Size(c), "\n");
      Print("Fail!\n");
      IO_WriteLine(f, "    [ fail, ", OnTuples(bg, g), ", ", Order(g), ", \"class of size ", Size(c), "\" ],");
    fi;
  fi;
od;

IO_WriteLine(f, "    [ fail, (), 1, \"one\"]");
IO_WriteLine(f, "  ]");
IO_WriteLine(f, ");");
IO_Flush(f);
IO_Close(f);

Print("\n--\n");
Print("The fusion of conjugacy classes:\n");

ct1 := CharacterTable("B");
ct2 := CharacterTable("S5xM22.2");

fus := FusionConjugacyClasses(ct2, ct1);
if not fus = fail then
  for t in [1..Size(fus)] do
    Print(ClassNames(ct2)[t], " --> ", ClassNames(ct1)[fus[t]], "\n");
  od;
else
  for fus in PossibleClassFusions(ct2, ct1) do
    for t in [1..Size(fus)] do
      Print(ClassNames(ct2)[t], " --> ", ClassNames(ct1)[fus[t]], ";\n");
    od;
    Print("--\n");
  od;
fi;

