LoadPackage("atlasrep");
LoadPackage("io");

checkD := function(gr, c)
  local sg, x, y;
  x := Representative(c);
  for y in c do
    if not (x*y)^2 = (y*x)^2 then 
      sg := Subgroup(gr, [x,y]);
      if IsConjugate(sg, x, y) = false then
        return [x,y];
      fi;
    fi;
  od;
  return fail;
end;

x := [];
g := [];
n := 0;

name := "Fi23";

LogTo("step7.log");

gr := DirectProduct(SymmetricGroup(4), AtlasGroup("S6(2)")); 
cc := ConjugacyClasses(gr);

bg := BaseOfGroup(gr);
Print("Base of Group: ", bg, "\n");

f := IO_File("step7.rec", "w");
IO_WriteLine(f,"### The format for classinfo is [ r, s, order, comment ]");
IO_WriteLine(f,"data := rec(");
IO_WriteLine(f,"  base := ", bg, ",");
IO_WriteLine(f,"  group := \"S4xS6(2)\",");
IO_WriteLine(f,"  comments := \"For classes with representatives of order 36\",");
IO_WriteLine(f,"  classinfo := [");


for c in cc do
  g := Representative(c);
  if Order(g) = 36 then
    Print("Checking conjugacy class with representative of order ", Order(g), "\n");
    rs := checkD(gr, c); 
    if not rs = fail then
      Print("r:=", OnTuples(bg, rs[1]), ";\n");
      Print("s:=", OnTuples(bg, rs[2]), ";\n");
      IO_WriteLine(f, "    [ ", OnTuples(bg, rs[1]), ", ", OnTuples(bg, rs[2]), ", ", Order(g), ", \"D\" ],");
    else
      Print("Size of the conjugacy class: ", Size(c), "\n");
      Print("Fail!\n");
      IO_WriteLine(f, "    [ fail, ", g, ", ", OnTuples(bg, Order(g)), ", \"class of size ", Size(c), "\" ],");

    fi;
  fi;
od;

IO_WriteLine(f, "    [ fail, (), 1, \"one\"]");
IO_WriteLine(f, "  ]");
IO_WriteLine(f, ");");
IO_Flush(f);
IO_Close(f);


