LoadPackage("atlasrep");
LoadPackage("io");

checkD := function(gr, c)
  local sg, x, y;
  x := Representative(c);
  for y in c do
    if not (x*y)^2 = (y*x)^2 then 
      sg := Subgroup(gr, [x,y]);
      if IsConjugate(sg, x, y) = false then
        return [x,y];
      fi;
    fi;
  od;
  return fail;
end;

x := [];
g := [];
n := 0;

name := "M22";

LogTo(Concatenation(name, ".log"));

M := Size(Maxes(CharacterTable(name)));

gr := AtlasGroup(name);
cc := ConjugacyClasses(gr);;
ct := CharacterTable(gr);;

bg := BaseOfGroup(gr);
Print("Base of Group: ", bg, "\n");

f := IO_File(Concatenation(name, ".rec"), "w");
IO_WriteLine(f,"### The format for classinfo is [ r, s, order, comment ]");
IO_WriteLine(f,"data := rec(");
IO_WriteLine(f,"  base := ", bg, ",");
IO_WriteLine(f,"  group := \"", name, "\",");
IO_WriteLine(f,"  comments := \"Maximal subgroups\",");
IO_WriteLine(f,"  classinfo := [");

cl := [];
for i in [1..Size(cc)] do
  g := Representative(cc[i]);
  if not Order(g) = 1 then
    Add(cl, i);
  fi;
od;

for i in [1..M] do
  _gr := Group(AtlasGenerators(name, 1, M+1-i).generators);
  _cc := ConjugacyClasses(_gr);

  Print("Maximal number: ", M+1-i, "\n");
  for c in _cc do
    g := Representative(c);
    n := Position(List(cc, x->g in x), true);
    if n in cl then
      Print("Checking: ", ClassNames(ct)[n], "\n");
      rs := checkD(_gr, c); 
      if not rs = fail then
	Print("r:=", OnTuples(bg, rs[1]), ";\n");
	Print("s:=", OnTuples(bg, rs[2]), ";\n");
        IO_WriteLine(f, "    [ ", OnTuples(bg, rs[1]), ", ", OnTuples(bg, rs[2]), ", ", Order(g), ", \"D\" ],");
        Print("Removed: ", ClassNames(ct)[n], "\nRemaining: ");
        Remove(cl, Position(cl, n));
        for j in cl do
          Print(ClassNames(ct)[j], " ");
        od;
        Print("\n--\n");
      fi;
    fi;
  od;
  Print("==\n");
od;

IO_WriteLine(f, "    [ fail, (), 1, \"one\"]");
IO_WriteLine(f, "  ]");
IO_WriteLine(f, ");");
IO_Flush(f);
IO_Close(f);

